@@ -1,5 +1,5 @@
 "onetPermutation" <-
-function(x=pair65$heated-pair65$ambient, nsim=2000, plotit=TRUE){
+function(x=DAAG::pair65$heated-DAAG::pair65$ambient, nsim=2000, plotit=TRUE){
 oldpar<-par(mar=par()$mar-c(1,0,1,0))
 on.exit(par(oldpar))
 n <- length(x)
