@@ -1,5 +1,5 @@
 twotPermutation <-
-function(x1=two65$ambient, x2=two65$heated, nsim=2000, plotit=TRUE){
+function(x1=DAAG::two65$ambient, x2=DAAG::two65$heated, nsim=2000, plotit=TRUE){
 # oldpar<-par(mar=par()$mar-c(1,0,1,0))
 # on.exit(par(oldpar))
 n1 <- length(x1)
